"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class SubmissionEventTypeResultTypeEnum(str, Enum):
    r"""Indicates that the routing form submission resulted in a redirect to an event type booking page."""
    EVENT_TYPE = 'event_type'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class SubmissionEventTypeResult:
    r"""Information about the event type Routing Form Submission result."""
    
    type: SubmissionEventTypeResultTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates that the routing form submission resulted in a redirect to an event type booking page."""  
    value: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('value') }})
    r"""A reference to the event type resource."""  
    