"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class LegacyCalendarEventKindEnum(str, Enum):
    r"""Indicates the calendar provider the event belongs to."""
    EXCHANGE = 'exchange'
    GOOGLE = 'google'
    ICLOUD = 'icloud'
    OUTLOOK = 'outlook'
    OUTLOOK_DESKTOP = 'outlook_desktop'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class LegacyCalendarEvent:
    r"""Information about the calendar event from the calendar provider."""
    
    external_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('external_id') }})
    r"""the id provided from the calendar provider for this calendar event."""  
    kind: LegacyCalendarEventKindEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('kind') }})
    r"""Indicates the calendar provider the event belongs to."""  
    