"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class OutboundCallTypeEnum(str, Enum):
    r"""Indicates that the event host (publisher) will call the invitee"""
    OUTBOUND_CALL = 'outbound_call'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class OutboundCall:
    r"""Meeting publisher will call the Invitee"""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The phone number the event host (publisher) will use to call the invitee"""  
    type: OutboundCallTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates that the event host (publisher) will call the invitee"""  
    