"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class EventTypeCustomQuestionTypeEnum(str, Enum):
    r"""The type of response that the invitee provides to the custom question; can be one or multiple lines of text, a phone number, or single- or multiple-select."""
    STRING = 'string'
    TEXT = 'text'
    PHONE_NUMBER = 'phone_number'
    SINGLE_SELECT = 'single_select'
    MULTI_SELECT = 'multi_select'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class EventTypeCustomQuestion:
    
    answer_choices: list[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('answer_choices') }})
    r"""The invitee’s option(s) for single_select or multi_select type of responses."""  
    enabled: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('enabled') }})
    r"""true if the question created by the host is turned ON and visible on the event booking page; false if turned OFF and invisible on the event booking page."""  
    include_other: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('include_other') }})
    r"""true if the custom question lets invitees record a written response in addition to single-select or multiple-select type of responses; false if it doesn’t."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The custom question that the host created for the event type."""  
    position: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('position') }})
    r"""The numerical position of the question on the event booking page after the name and email address fields."""  
    required: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('required') }})
    r"""true if a response to the question created by the host is required for invitees to book the event type; false if not required."""  
    type: EventTypeCustomQuestionTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The type of response that the invitee provides to the custom question; can be one or multiple lines of text, a phone number, or single- or multiple-select."""  
    