"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class InboundCallTypeEnum(str, Enum):
    r"""Indicates that the invitee will call the event host"""
    INBOUND_CALL = 'inbound_call'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InboundCall:
    r"""Invitee will call meeting publisher at the specified phone number"""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The phone number the invitee will use to call the event host (publisher)"""  
    type: InboundCallTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates that the invitee will call the event host"""  
    