"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class QuestionTypeEnum(str, Enum):
    r"""Question type: name, text input, email, phone, textarea input, dropdown list or radio button list."""
    NAME = 'name'
    TEXT = 'text'
    EMAIL = 'email'
    PHONE = 'phone'
    TEXTAREA = 'textarea'
    SELECT = 'select'
    RADIOS = 'radios'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Question:
    r"""Routing form questions."""
    
    answer_choices: list[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('answer_choices') }})
    r"""The respondent’s option(s) for \\"select\\" or \\"radios\\" types of questions."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""Question name (in human-readable format)."""  
    required: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('required') }})
    r"""true if an answer to the question is required for respondents to submit the routing form; false if not required."""  
    type: QuestionTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Question type: name, text input, email, phone, textarea input, dropdown list or radio button list."""  
    uuid: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uuid') }})
    r"""Unique identifier for the routing form question."""  
    