"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class InviteeSpecifiedLocationTypeEnum(str, Enum):
    r"""The event location selected by the invitee"""
    ASK_INVITEE = 'ask_invitee'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteeSpecifiedLocation:
    r"""Information about an event location that’s specified by the invitee."""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The event location description provided by the invitee"""  
    type: InviteeSpecifiedLocationTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location selected by the invitee"""  
    